@@ -2,7 +2,7 @@ package LWP::Protocol;
 
 use parent 'LWP::MemberMixin';
 
-our $VERSION = '6.68';
+our $VERSION = '6.69';
 
 use strict;
 use Carp ();
@@ -12,6 +12,7 @@ use Scalar::Util qw(openhandle);
 use Try::Tiny qw(try catch);
 
 my %ImplementedBy = (); # scheme => classname
+my %ImplementorAlreadyTested;
 
 sub new
 {
@@ -49,13 +50,15 @@ sub implementor
     if ($impclass) {
 	$ImplementedBy{$scheme} = $impclass;
     }
-    my $ic = $ImplementedBy{$scheme};
-    return $ic if $ic;
 
     return '' unless $scheme =~ /^([.+\-\w]+)$/;  # check valid URL schemes
     $scheme = $1; # untaint
     $scheme =~ tr/.+-/_/;  # make it a legal module name
 
+    my $ic = $ImplementedBy{$scheme};
+    # module does not exist
+    return $ic if $ic || $ImplementorAlreadyTested{$scheme};
+
     # scheme not yet known, look for a 'use'd implementation
     $ic = "LWP::Protocol::$scheme";  # default location
     $ic = "LWP::Protocol::nntp" if $scheme eq 'news'; #XXX ugly hack
@@ -79,6 +82,7 @@ sub implementor
         };
     }
     $ImplementedBy{$scheme} = $ic if $ic;
+    $ImplementorAlreadyTested{$scheme} = 1;
     $ic;
 }
 
