@@ -17,7 +17,7 @@ use LWP::Protocol ();
 use Scalar::Util qw(blessed openhandle);
 use Try::Tiny qw(try catch);
 
-our $VERSION = '6.68';
+our $VERSION = '6.69';
 
 sub new
 {
@@ -712,7 +712,21 @@ sub get_basic_credentials
 }
 
 
-sub timeout      { shift->_elem('timeout',      @_); }
+sub timeout
+{
+    my $self = shift;
+    my $old = $self->{timeout};
+    if (@_) {
+        $self->{timeout} = shift;
+        if (my $conn_cache = $self->conn_cache) {
+            for my $conn ($conn_cache->get_connections) {
+                $conn->timeout($self->{timeout});
+            }
+        }
+    }
+    return $old;
+}
+
 sub local_address{ shift->_elem('local_address',@_); }
 sub max_size     { shift->_elem('max_size',     @_); }
 sub max_redirect { shift->_elem('max_redirect', @_); }
@@ -845,16 +859,21 @@ sub from {  # legacy
 
 sub conn_cache {
     my $self = shift;
-    my $old = $self->{conn_cache};
+    my $old  = $self->{conn_cache};
     if (@_) {
-	my $cache = shift;
-	if (ref($cache) eq "HASH") {
-	    require LWP::ConnCache;
-	    $cache = LWP::ConnCache->new(%$cache);
-	}
-	$self->{conn_cache} = $cache;
+        my $cache = shift;
+        if ( ref($cache) eq "HASH" ) {
+            require LWP::ConnCache;
+            $cache = LWP::ConnCache->new(%$cache);
+        }
+        elsif ( defined $cache)  {
+            for my $conn ( $cache->get_connections ) {
+                $conn->timeout( $self->timeout );
+            }
+        }
+        $self->{conn_cache} = $cache;
     }
-    $old;
+    return $old;
 }
 
 
@@ -1073,7 +1092,7 @@ sub _need_proxy {
     if ($ua->{no_proxy}) {
         if (my $host = eval { $req->uri->host }) {
             for my $domain (@{$ua->{no_proxy}}) {
-                if ($host =~ /\Q$domain\E$/) {
+                if ($host =~ /(?:^|\.)\Q$domain\E$/) {
                     return;
                 }
             }
